<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="374"/>
        <source>Cannot generate random number by TPM</source>
        <translation>Nem generálható véletlen szám a TPM segítségével </translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="377"/>
        <source>No available encrypt algorithm.</source>
        <translation>Nincs elérhető titkosítási algoritmus.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="380"/>
        <source>TPM encrypt failed.</source>
        <translation>A TPM titkosítása sikertelen.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="383"/>
        <source>TPM is locked.</source>
        <translation>A TPM zárolva.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="411"/>
        <source>Confirm encrypt %1?</source>
        <translation>Biztosan titkosítja a %1-t?</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="414"/>
        <source>The current partition is about to be encrypted and cannot be canceled during the encryption process, please confirm the encryption.</source>
        <translation>A jelenlegi partició titkosítása folyamatban van, és a titkosítás közben nem húzható vissza, kérjük, jóváhagyja a titkosítást.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="421"/>
        <source>* After encrypting the partition, the system cannot be rolled back to a lower version, please confirm the encryption</source>
        <translation>* A partició titkosítása után a rendszer nem húzható vissza egy korábbi verzióra, kérjük, jóváhagyja a titkosítást</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="432"/>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="433"/>
        <source>Confirm and Reboot</source>
        <translation>Jóváhagyás és újraindítás</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="434"/>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="444"/>
        <source>Decrypt %1?</source>
        <translation>Titkosítás feloldása %1?</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="445"/>
        <source>Decryption can take a long time, so make sure power is connected until the decryption is complete.</source>
        <translation>A titkosítás feloldása hosszú ideig tart, így biztosítson áramellátást a feloldás befejezéséig.</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::ChgPassphraseDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="18"/>
        <source>passphrase</source>
        <translation>Jelszó</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="20"/>
        <source>PIN</source>
        <translation>PIN-kód</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="109"/>
        <source>Recovery key</source>
        <translation>Helyreállítási kulcs</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="171"/>
        <source>Validate with %1</source>
        <translation>Érvényesítés a %1-el</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="172"/>
        <source>Please input recovery key</source>
        <translation>Kérjük  adja meg a helyreállítási kulcsot</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="174"/>
        <source>Old %1</source>
        <translation>Régi %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="70"/>
        <source>New %1</source>
        <translation>Új %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="56"/>
        <source>Modify %1</source>
        <translation>Módosítás %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="67"/>
        <source>Please enter %1 again</source>
        <translation>Kérjük adja meg a %1-et mégegyszer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="71"/>
        <source>Repeat %1</source>
        <translation>Ismétlés %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="77"/>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="78"/>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="101"/>
        <source>%1 cannot be empty</source>
        <translation>A %1 nem lehet üres</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="115"/>
        <source>Recovery key is not valid!</source>
        <translation>A helyreállítási kulcs nem érvényes!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="140"/>
        <source>At least 8 bits, contains 3 types of A-Z, a-z, 0-9 and symbols</source>
        <translation>Legalább 8 bit, 3 típusú A-Z, a-z, 0-9 és szimbólumokat tartalmaz </translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="145"/>
        <source>%1 inconsistency</source>
        <translation>%1 inkonzisztencia</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="177"/>
        <source>Validate with recovery key</source>
        <translation>Érvényesítse a helyreállítási kulccsal</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::DecryptParamsInputDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="52"/>
        <source>Validate with %1</source>
        <translation>Érvényesítés a %1-el</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="52"/>
        <source>PIN</source>
        <translation>PIN-kód</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="52"/>
        <source>passphrase</source>
        <translation>Jelszó</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="56"/>
        <source>Please input %1 to decrypt device</source>
        <translation>Kérjük adja meg a %1-et a lemez visszafejtéséhez</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="103"/>
        <source>Decrypt device</source>
        <translation>Eszköz visszafejtése</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="51"/>
        <source>Please input recovery key to decrypt device</source>
        <translation>Kérjük adja meg a helyreálíítási kulcsot a lemez visszafejtéséhez</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="57"/>
        <source>Validate with recovery key</source>
        <translation>Érvényesítse a helyreállítási kulccsal</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="79"/>
        <source>Passphrase</source>
        <translation>Jelszó</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="81"/>
        <source>Recovery key</source>
        <translation>Helyreállítási kulcs</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="82"/>
        <source>%1 cannot be empty!</source>
        <translation>A %1 nem lehet üres!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="87"/>
        <source>Recovery key is not valid!</source>
        <translation>A helyreállítási kulcs nem érvényes!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="111"/>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::DiskEncryptMenuScene</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="148"/>
        <source>Unlock encrypted partition</source>
        <translation>A titkosított partíció feloldása</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="152"/>
        <source>Cancel partition encryption</source>
        <translation>A partíció titkosításának megszakítása</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="156"/>
        <source>passphrase</source>
        <translation>Jelszó</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="157"/>
        <source>Changing the encryption %1</source>
        <translation>A titkosítás módosítása %1 -re</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="161"/>
        <source>Continue partition encryption</source>
        <translation>Particionális titkosítás folytatása</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="165"/>
        <source>Continue partition decryption</source>
        <translation>Particionális titkosítás feloldása folytatása</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="169"/>
        <source>Enable partition encryption</source>
        <translation>A partíció titkosításának engedélyezése</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="225"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="226"/>
        <source>Cannot resolve passphrase from TPM</source>
        <translation>Nem sikerült feloldani a jelszót a TPM-ből</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="248"/>
        <source>PIN error</source>
        <translation>PIN kód hiba</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="276"/>
        <source>Change passphrase failed</source>
        <translation>Jelszó megváltoztatása sikertelen</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="525"/>
        <source>Unlock device failed</source>
        <translation>Az eszköz feloldása sikertelen</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="526"/>
        <source>Wrong passphrase</source>
        <translation>Helytelen jelszó</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="544"/>
        <source>Mount device failed</source>
        <translation>Az eszköz csatolása sikertelen</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="587"/>
        <source>unmount</source>
        <translation>Leválasztás</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="587"/>
        <source>lock</source>
        <translation>Zárolás</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="588"/>
        <source>Encrypt failed</source>
        <translation>A visszafejtés sikertelen</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="589"/>
        <source>Cannot %1 device %2</source>
        <translation>Nem sikerült %1 eszköz %2</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="673"/>
        <source>Reboot to continue encrypt</source>
        <translation>Újraindítás a titkosítás folytatásához</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="674"/>
        <source>Reboot to finish decrypt</source>
        <translation>Újraindítás a titkosítás feloldásának befejezéséhez</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::EncryptParamsInputDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="130"/>
        <source>Unlocked by passphrase</source>
        <translation>Jelszóval feloldva</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="157"/>
        <source>In special cases such as forgetting the password or the encryption hardware is damaged, you can decrypt the encrypted partition with the recovery key, please export it to a non-encrypted partition and keep it in a safe place!</source>
        <translation>Speciális esetekben, mint például a jelszó elfelejtése vagy a titkosító hardver megsérülése, a titkosított partíciót a helyreállítási kulccsal visszafejthető, kérjük exportálja nem titkosított partícióra és tartsa biztonságos helyen a kulcsot! </translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="172"/>
        <source>Please select a non-encrypted partition as the key file export path.</source>
        <translation>Kérjük válasszon egy nem titkosított partíciót a kulcsfájl exportálási útjaként.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="192"/>
        <source>Passphrase</source>
        <translation>Jelszó</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="194"/>
        <source>%1 cannot be empty</source>
        <translation>A %1 nem lehet üres</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="225"/>
        <source>%1 inconsistency</source>
        <translation>%1 inkonzisztencia</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="236"/>
        <source>Recovery key export path cannot be empty!</source>
        <translation>A helyreállítási kulcs exportálási útvonala nem lehet üres! </translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="241"/>
        <source>Recovery key export path is not exists!</source>
        <translation>A helyreállítási kulcs exportálási útvonala nem létezik! </translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="248"/>
        <source>Please export to an external device such as a non-encrypted partition or USB flash drive.</source>
        <translation>Exportáljon külső eszközre, például nem titkosított partícióra vagy USB flash meghajtóra.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="253"/>
        <source>This partition is read-only, please export to a writable partition</source>
        <translation>Ez a partició csakolvasásra van állítva, kérjük, exportálja egy írható particióba</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="265"/>
        <source>The partition is encrypted, please export to a non-encrypted partition or external device such as a USB flash drive.</source>
        <translation>A partíció titkosított, kérjük exportálja egy nem titkosított partícióra vagy külső eszközre, például USB flash meghajtóra. 
 
 </translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="421"/>
        <source>TPM is locked and cannot be used for partition encryption. Please cancel the TPM password or choose another unlocking method.</source>
        <translation>A TPM zárolt, és nem használható partició titkosítására. Kérjük, törölje a TPM jelszót vagy válasszon más megoldást.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="423"/>
        <source>TPM error</source>
        <translation type="unfinished">TPM hiba</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="426"/>
        <source>TPM status error!</source>
        <translation>TPM hibás állapot!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="317"/>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="316"/>
        <source>Please continue to encrypt partition %1</source>
        <translation>Kérjük, folytassa a %1 partició titkosítását</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="321"/>
        <source>Previous</source>
        <translation>Előző</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="320"/>
        <source>Export Recovery Key</source>
        <translation>Helyreállítási kulcs exportálása</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="329"/>
        <source>Set %1</source>
        <translation>%1 beállítása</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="330"/>
        <source>Repeat %1</source>
        <translation>%1 ismétlése</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="336"/>
        <source>passphrase</source>
        <translation>Jelszó</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="340"/>
        <source>Access to the partition will be unlocked using a passphrase.</source>
        <translation>A partícióhoz való hozzáférés egy jelszó segítségével fel van oldva.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="347"/>
        <source>Access to the partition will be unlocked using the TPM security chip and PIN.</source>
        <translation>A partícióhoz való hozzáférés egy TPM biztonsági chip és PIN kód használatával fel van oldva.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="350"/>
        <source>Access to the partition will be automatically unlocked using the TPM security chip, no passphrase checking is required.</source>
        <translation>A partícióhoz való hozzáférés egy TPM biztonsági chip használatával fel van oldva, a jelszó ellenőrzése nem szükséges.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="332"/>
        <source>Please enter the %1 again</source>
        <translation>Kérjük adja meg a %1-et mégegyszer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="110"/>
        <source>Unlock type</source>
        <translation>Feloldás típusa </translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="131"/>
        <source>Use TPM+PIN to unlock on this computer (recommended)</source>
        <translation>Használja a TPM+PIN kódot a zárolás feloldásához ezen a számítógépen (ajánlott)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="132"/>
        <source>Automatic unlocking on this computer by TPM</source>
        <translation>Automatikus feloldás ezen a számítógépen TPM segítségével</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="220"/>
        <source>At least 8 bits, contains 3 types of A-Z, a-z, 0-9 and symbols</source>
        <translation>Legalább 8 bit, 3 típusú A-Z, a-z, 0-9 és szimbólumokat tartalmaz </translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="317"/>
        <source>Confirm encrypt</source>
        <translation>Titkosítás jóváhagyása</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="343"/>
        <source>PIN</source>
        <translation>PIN-kód</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::EncryptProgressDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="54"/>
        <source>Confirm</source>
        <translation type="unfinished">Megerősítés</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="63"/>
        <source>Re-export the recovery key</source>
        <translation>Visszaexportálás a visszaállító kulcs</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="67"/>
        <source>*Recovery key saving failed, please re-save the recovery key to a non-encrypted partition and keep it in a safe place!</source>
        <translation>*Visszaállító kulcs mentése sikertelen, kérjük, mentse újra a visszaállító kulcsot egy titkosítatlan particióba, és tartson rá biztonságban!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="82"/>
        <source>Error</source>
        <translation type="unfinished">Hiba</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="143"/>
        <source>Recovery key export path cannot be empty!</source>
        <translation type="unfinished">A helyreállítási kulcs exportálási útvonala nem lehet üres! </translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="148"/>
        <source>Recovery key export path is not exists!</source>
        <translation type="unfinished">A helyreállítási kulcs exportálási útvonala nem létezik! </translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="154"/>
        <source>This partition is read-only, please export to a writable partition</source>
        <translation>Ez a partició csakolvasásra van állítva, kérjük, exportálja egy írható particióba</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="167"/>
        <source>The partition is encrypted, please export to a non-encrypted partition or external device such as a USB flash drive.</source>
        <translation type="unfinished">A partíció titkosított, kérjük exportálja egy nem titkosított partícióra vagy külső eszközre, például USB flash meghajtóra. 
 
 </translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="183"/>
        <source>Cannot create recovery key file!</source>
        <translation>Nem hozható létre visszaállító kulcs fájl!</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::EventsHandler</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="424"/>
        <source>Preencrypt done</source>
        <translation>Előtitkosítás kész</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="425"/>
        <source>Device %1 has been preencrypt, please reboot to finish encryption.</source>
        <translation>A %1 eszköz előtitkosított, kérjük indítsa újra a titkosítás befejezéséhez.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="431"/>
        <source>Preencrypt failed</source>
        <translation>Előtitkosítás sikertelen</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="432"/>
        <source>Device %1 preencrypt failed, please see log for more information.(%2)</source>
        <translation>A %1 eszköz előtitkosítása sikertelen, kérjük tekintse meg a naplót a további részletekért (%2)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="460"/>
        <source>Wrong passpharse or PIN</source>
        <translation>Helytelen jelkód vagy PIN kód</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="496"/>
        <source>passphrase</source>
        <translation>Jelszó</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="499"/>
        <source>PIN</source>
        <translation>PIN kód</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="506"/>
        <source>Change %1 done</source>
        <translation>%1 módosítása kész</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="507"/>
        <source>%1's %2 has been changed</source>
        <translation>A %1's %2 megváltozott</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="512"/>
        <source>Change %1 failed</source>
        <translation>%1 módosítása sikertelen</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="513"/>
        <source>Wrong %1</source>
        <translation>Helytelen %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="518"/>
        <source>Device %1 change %2 failed, please see log for more information.(%3)</source>
        <translation>%1 eszköz megváltoztatva, %2 sikertelen, kérjük tekintse meg a naplót a további részletekért (%3)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="180"/>
        <source>Encrypt done</source>
        <translation>Visszafejtés kész</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="181"/>
        <source>Device %1 has been encrypted</source>
        <translation>A %1 eszköz visszafejtve</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="185"/>
        <source>Encrypt failed</source>
        <translation>A visszafejtés sikertelen</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="186"/>
        <source>Device %1 encrypt failed, please see log for more information.(%2)</source>
        <translation>A %1 eszköz titkosítása sikertelen, kérjük tekintse meg a naplót a további részletekért (%2)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="285"/>
        <source>%1 is under encrypting...</source>
        <translation>A %1 titkosítása folyamatban...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="286"/>
        <source>The encrypting process may have system lag, please minimize the system operation</source>
        <translation>A titkosítási folyamat rendszer lassulását, akadozását eredményezheti, kérjük minimalizálja a rendszer műveleteket</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="305"/>
        <source>%1 is under decrypting...</source>
        <translation>A %1 visszafejtése folyamatban...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="306"/>
        <source>The decrypting process may have system lag, please minimize the system operation</source>
        <translation>A visszafejtési folyamat rendszer lassulását, akadozását eredményezheti, kérjük minimalizálja a rendszer műveleteket</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="331"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="452"/>
        <source>Decrypt done</source>
        <translation>Visszafejtés kész</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="453"/>
        <source>Device %1 has been decrypted</source>
        <translation>A %1 eszköz visszafejtve</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="459"/>
        <source>Decrypt disk</source>
        <translation>Lemez visszafejtése</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="463"/>
        <source>Decrypt failed</source>
        <translation>A visszafejtés sikertelen</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="464"/>
        <source>Device %1 is under encrypting, please decrypt after encryption finished.</source>
        <translation>A %1 eszköz titkosítása folyamatban van, kérjük, titkosítás befejezése után oldja fel.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="469"/>
        <source>Device %1 Decrypt failed, please see log for more information.(%2)</source>
        <translation>A %1 eszköz visszafejtése sikertelen, kérjük tekintse meg a naplót a további részletekért (%2)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="547"/>
        <source>Device is not fully decrypted, please finish decryption before access.</source>
        <translation>Az eszköz nem teljesen fel lett oldva, kérjük, fejezze be a feloldást a hozzáférés előtt.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="554"/>
        <source>Unlocking device failed</source>
        <translation>Eszköz megfeleltetése sikertelen</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="555"/>
        <source>Please click the right disk menu "Continue partition encryption" to complete partition encryption.</source>
        <translation>Kérjük, kattintson a jobb oldali lemezmenüre "Particionális titkosítás folytatása", hogy befejezze a partició titkosítását.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="331"/>
        <source>TPM status is abnormal, please use the recovery key to unlock it</source>
        <translation>A TPM állapota rendellenes, kérjük használja a helyreállítási kulcsot a feloldáshoz</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="357"/>
        <source>Wrong PIN</source>
        <translation>Helytelen PIN kód</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="359"/>
        <source>Wrong passphrase</source>
        <translation>Helytelen jelszó</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="361"/>
        <source>TPM error</source>
        <translation>TPM hiba</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="363"/>
        <source>Please use recovery key to unlock device.</source>
        <translation>Kérjük használja a helyreállítási kulcsot az eszköz feloldásához.</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::UnlockPartitionDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="51"/>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="52"/>
        <source>Unlock</source>
        <translation>Feloldás</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="81"/>
        <source>Unlock encryption partition</source>
        <translation>Titkosított partíció feloldása</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="85"/>
        <source>Unlock by recovery key</source>
        <translation>Feloldás helyreállítási kulccsal</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="90"/>
        <source>Unlock by passphrase</source>
        <translation>Feloldás jelszóval</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="91"/>
        <source>Unlock by PIN</source>
        <translation>Feloldás PIN kóddal</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="93"/>
        <source>Please input recovery key to unlock device</source>
        <translation>Kérjük adja meg a helyreállítási kulcsot az eszköz feloldásához</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="99"/>
        <source>Please input passphrase to unlock device</source>
        <translation>Kérjük adja meg a jelszót az eszköz feloldásához</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="102"/>
        <source>Please input PIN to unlock device</source>
        <translation>Kérjük adja meg a PIN kódot az eszköz feloldásához</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="115"/>
        <source>Recovery key is not valid!</source>
        <translation>A helyreállítási kulcs nem érvényes!</translation>
    </message>
</context>
</TS>
